#
# spec file for package lua-fennel
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2020 Fabio Pesari
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lua-fennel
Version:        1.2.1
Release:        2.4
Summary:        Lisp dialect that compiles to Lua
License:        MIT
Group:          Development/Languages/Lua
URL:            https://fennel-lang.org/
Source0:        https://git.sr.ht/~technomancy/fennel/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  lua
BuildArch:      noarch

%description
Fennel is a lisp that compiles to Lua. Features include:

• Full Lua compatibility - You can use any function or library from
  Lua.
• Zero overhead - Compiled code should be just as or more efficient
  than hand-written Lua.
• Compile-time macros - Ship compiled code with no runtime
  dependency on Fennel.
• Embeddable - Fennel is a one-file library as well as an
  executable.
  Embed it in other programs to support runtime extensibility and
  interactive development.

%prep
%autosetup -p1 -n fennel-%{version}

%build
make %{?_make_output_sync} %{?_smp_mflags} fennel

%check
make %{?_make_output_sync} %{?_smp_mflags} test

%install
mkdir -p %{buildroot}%{_bindir}
sed -i s:%{_bindir}/env\ lua:%{_bindir}/lua: fennel
install -m 755 fennel %{buildroot}%{_bindir}

%files
%doc README.md api.md changelog.md reference.md tutorial.md
%license LICENSE
%{_bindir}/fennel

%changelog
* Wed Jan 25 2023 Michal Suchanek <msuchanek@suse.de>
- Opencode %%make_build to prevent build failure when not defined.
* Fri Oct 21 2022 Mia Herkt <mia@0x0.st>
- Update to 1.2.1
  New Features
  * Add `fennel.install` function to the API for adding the
    searcher
  * Add missing `table?` predicate to fennel API to go with
    `list?`, `sym?`, etc
  Bug Fixes
  * Skip autogenerated locals in repl locals saving to avoid
    exceeding local limit
  * Ensure `(values)` consistently evaluates to zero values
  * Fix bug preventing new macros from shadowing other macros
  * Ensure macros use stable `pairs` table traversal for
    reproducible builds
- Changes in 1.2.0:
  New Forms
  * Add `fcollect` macro for range "comprehension"
  New Features
  * Make `include` splice modules in where they're used instead of
    at the top
  * Add `ast-source` function to API to get file/line info from
    AST nodes
  * Show errors using terminal control codes instead of arrow
    indicator
  * Parser now includes column information (byte-based) in AST
    nodes
  * For greater consistency, add `&into`/`&until` to certain
    looping constructs
  Bug Fixes
  * Duplicate table keys no longer crash the compiler
  * Don't print stack trace for compiler errors in built-in macros
  * Fix an issue with native modules in `--compile-binary`
  * Improve argument handling so unused arguments get passed on to
    script
  * Fix a bug where macros modifying table literals would emit
    incorrect output
  * Fix a bug in the REPL where parser errors display the error
    message as `nil`
  * Fix a bug when `nil` were emitted by `unquote` in a macro,
    and the macro was not compiled correctly because the resulting
    list length was calculated incorrectly
  * Fix a REPL bug where `,doc m.foo` did not resolve multisym to
    macro for macro modules loaded as macro table via
    `(import-macros m :my.macro.module)`
  Changes in 1.1.0:
  New Forms
  * Add `match-try` macro for chained pattern matching for steps
    which might fail
  New Features
  * The `fennel.parser` function now accepts a string in addition
    to an iterator
  * The `accumulate` macro can now accumulate over multiple values
  * The `fn` special now accepts a metadata table in place of a
    docstring
  * The `,reload mod` repl command can now reload macro modules
  Bug Fixes
  * Fix an issue where built-in macros would modify their AST
    arguments
  * Fix a bug where  `--skip-include` would mistakenly emit a
    warning
  * Remove hex string escapes to preserve PUC Lua 5.1 compatibility
  * Prevent errors resolving the target of certain repl commands
    from crashing
  * Fix a bug where disabling the compiler sandbox broke module
    require scope
  * Fix a bug where certain specials wouldn't short-circuit in
    `and`/`or`
  * Fix a bug where symbols bound to `nil` did not show up in REPL
    completion
  Changes and Removals
  * Deprecate the `granulate` and `string-stream` functions in the
    API
  * Deprecate the `global` form in favor of using the `_G` table
* Mon Nov 15 2021 Fabio Pesari <fpesari@tuxfamily.org>
- Updated to 1.0.0
* Sat Aug 28 2021 Matej Cepl <mcepl@suse.com>
- Update to 0.10.0 and trying to make the build working.
  Number of changes is just too long and changelog.md is packaged.
* Sat Jun  6 2020 Fabio Pesari <fpesari@tuxfamily.org>
- First upload, v0.4.1
